@@ -5,14 +5,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': 'python3.6 /builddir/build/BUILD/Python-3.6.1/Parser/asdl_c.py',
- 'ASDLGEN_FILES': '/builddir/build/BUILD/Python-3.6.1/Parser/asdl.py '
-                  '/Parser/asdl_c.py',
- 'AST_ASDL': '/builddir/build/BUILD/Python-3.6.1/Parser/Python.asdl',
- 'AST_C': 'Python/Python-ast.c',
- 'AST_C_DIR': 'Python',
- 'AST_H': 'Include/Python-ast.h',
- 'AST_H_DIR': 'Include',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
@@ -34,6 +26,7 @@ build_time_vars = {'ABIFLAGS': 'm',
            '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 -D_GNU_SOURCE -fPIC '
            '-fwrapv',
  'CFLAGSFORSHARED': '-fPIC',
+ 'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
@@ -62,7 +55,8 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'--with-dbmliborder=gdbm:ndbm:bdb' '--with-system-expat' "
                 "'--with-system-ffi' '--enable-loadable-sqlite-extensions' "
                 "'--with-dtrace' '--with-lto' '--with-valgrind' "
-                "'--without-ensurepip' 'build_alias=aarch64-redhat-linux-gnu' "
+                "'--without-ensurepip' '--disable-optimizations' "
+                "'build_alias=aarch64-redhat-linux-gnu' "
                 "'host_alias=aarch64-redhat-linux-gnu' 'CFLAGS=-O2 -g -pipe "
                 '-Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                 '-fexceptions -fstack-protector-strong '
@@ -74,12 +68,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.6m',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.6.1/build/optimized/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.6.1/build/optimized/lcov-report',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.6.2/build/optimized/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.6.2/build/optimized/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.6.1/Include',
+             '-I/builddir/build/BUILD/Python-3.6.2/Include',
  'CXX': 'g++ -pthread',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.6 '
              '/usr/lib64/python3.6/lib-dynload',
@@ -118,9 +112,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'GITTAG': '',
  'GITVERSION': '',
  'GNULD': 'yes',
- 'GRAMMAR_C': 'Python/graminit.c',
- 'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': '/builddir/build/BUILD/Python-3.6.1/Grammar/Grammar',
  'HAVE_ACCEPT4': 1,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
@@ -551,7 +542,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.6.1/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.6.2/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODLIBS': '',
@@ -577,16 +568,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPCODETARGETGEN': '\\',
- 'OPCODETARGETGEN_FILES': '\\',
- 'OPCODETARGETS_H': '\\',
- 'OPCODE_H': '/builddir/build/BUILD/Python-3.6.1/Include/opcode.h',
- 'OPCODE_H_DIR': '/builddir/build/BUILD/Python-3.6.1/Include',
- 'OPCODE_H_GEN': 'python3.6 '
-                 '/builddir/build/BUILD/Python-3.6.1/Tools/scripts/generate_opcode_h.py '
-                 '/Lib/opcode.py '
-                 '/builddir/build/BUILD/Python-3.6.1/Include/opcode.h',
- 'OPCODE_H_SCRIPT': '/builddir/build/BUILD/Python-3.6.1/Tools/scripts/generate_opcode_h.py',
  'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -O2 -g -pipe -Wall '
         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
         '-fstack-protector-strong --param=ssp-buffer-size=4 '
@@ -620,7 +601,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_GEN': 'python3.6',
+ 'PYTHON_FOR_REGEN': 'python3.6',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
@@ -642,10 +623,10 @@ build_time_vars = {'ABIFLAGS': 'm',
                    '-D_GNU_SOURCE -fPIC -fwrapv -std=c99 -Wextra '
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -IObjects -IInclude '
-                   '-IPython -I. -I/builddir/build/BUILD/Python-3.6.1/Include  '
+                   '-IPython -I. -I/builddir/build/BUILD/Python-3.6.2/Include  '
                    '-DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.6.1/Include',
+                '-I/builddir/build/BUILD/Python-3.6.2/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-z,relro -specs=/usr/lib/rpm/redhat/redhat-hardened-ld',
  'PY_WARN_ON_C_LOCALE': 1,
@@ -657,7 +638,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.6.1/build/optimized',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.6.2/build/optimized',
  'SCRIPTDIR': '/usr/lib64',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -685,7 +666,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-36m-aarch64-linux-gnu',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.6.1/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.6.2/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -698,10 +679,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.6.1/build/optimized '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.6.2/build/optimized '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.6.1/build/optimized '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.6.2/build/optimized '
                './python /Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
@@ -713,7 +694,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'USE_COMPUTED_GOTOS': 1,
  'USE_INLINE': 1,
  'VERSION': '3.6',
- 'VPATH': '/builddir/build/BUILD/Python-3.6.1',
+ 'VPATH': '/builddir/build/BUILD/Python-3.6.2',
  'WANT_SIGFPE_HANDLER': 0,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
@@ -726,9 +707,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.6.1/build/optimized',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.6.1',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.6.2/build/optimized',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.6.2',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.6.1'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.6.2'}
